data

package
v0.0.0-...-0183ee3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Employees = []*projects.Employee{
	{
		Id: 1,
		Projects: &projects.ListOfProject{
			List: &projects.ListOfProject_List{
				Items: []*projects.Project{ServiceProjects[0], ServiceProjects[3]},
			},
		},
		AssignedTasks:  GetAssignedTasksByEmployeeId(1),
		CompletedTasks: GetCompletedTasksByEmployeeId(1),

		Skills: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"AWS", "Kubernetes", "Infrastructure"},
			},
		},
		Certifications: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"AWS Solutions Architect", "CKA"},
			},
		},
		ProjectHistory: GetProjectHistoryByEmployeeId(1),
	},
	{
		Id: 2,
		Projects: &projects.ListOfProject{
			List: &projects.ListOfProject_List{
				Items: []*projects.Project{ServiceProjects[0], ServiceProjects[1], ServiceProjects[4]},
			},
		},
		AssignedTasks:  GetAssignedTasksByEmployeeId(2),
		CompletedTasks: GetCompletedTasksByEmployeeId(2),

		Skills: nil,
		Certifications: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"GCP Professional Cloud Architect"},
			},
		},
		ProjectHistory: GetProjectHistoryByEmployeeId(2),
	},
	{
		Id: 3,
		Projects: &projects.ListOfProject{
			List: &projects.ListOfProject_List{
				Items: []*projects.Project{ServiceProjects[0], ServiceProjects[5]},
			},
		},
		AssignedTasks:  GetAssignedTasksByEmployeeId(3),
		CompletedTasks: GetCompletedTasksByEmployeeId(3),

		Skills: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"Networking", "Security", "Monitoring"},
			},
		},
		Certifications: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"CISSP", "CCNA"},
			},
		},
		ProjectHistory: GetProjectHistoryByEmployeeId(3),
	},
	{
		Id: 4,
		Projects: &projects.ListOfProject{
			List: &projects.ListOfProject_List{
				Items: []*projects.Project{ServiceProjects[1]},
			},
		},
		AssignedTasks:  GetAssignedTasksByEmployeeId(4),
		CompletedTasks: GetCompletedTasksByEmployeeId(4),
		Skills: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"Java", "Spring", "Microservices"},
			},
		},
		Certifications: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"Oracle Certified Professional Java SE"},
			},
		},
		ProjectHistory: GetProjectHistoryByEmployeeId(4),
	},
	{
		Id: 5,
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{
			Items: []*projects.Project{ServiceProjects[2], ServiceProjects[6]},
		}},
		AssignedTasks:  GetAssignedTasksByEmployeeId(5),
		CompletedTasks: GetCompletedTasksByEmployeeId(5),
		Skills: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"Python", "Machine Learning", "Data Science"},
			},
		},
		Certifications: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"Google Professional Data Engineer"},
			},
		},
		ProjectHistory: GetProjectHistoryByEmployeeId(5),
	},
	{
		Id: 6,
		Projects: &projects.ListOfProject{
			List: &projects.ListOfProject_List{
				Items: []*projects.Project{ServiceProjects[2]},
			},
		},
		AssignedTasks:  GetAssignedTasksByEmployeeId(6),
		CompletedTasks: GetCompletedTasksByEmployeeId(6),
		Skills: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"TensorFlow", "PyTorch", "Computer Vision"},
			},
		},
		Certifications: &projects.ListOfString{
			List: &projects.ListOfString_List{
				Items: []string{"AWS Certified Machine Learning"},
			},
		},
		ProjectHistory: GetProjectHistoryByEmployeeId(6),
	},
	{
		Id: 7,
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{
			Items: []*projects.Project{ServiceProjects[1]},
		}},
		AssignedTasks:  GetAssignedTasksByEmployeeId(7),
		CompletedTasks: GetCompletedTasksByEmployeeId(7),
		Skills: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"System Architecture", "Distributed Systems"},
		}},
		Certifications: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"TOGAF 9 Certified"},
		}},
		ProjectHistory: GetProjectHistoryByEmployeeId(7),
	},
	{
		Id: 8,
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{
			Items: []*projects.Project{ServiceProjects[1]},
		}},
		AssignedTasks:  GetAssignedTasksByEmployeeId(8),
		CompletedTasks: GetCompletedTasksByEmployeeId(8),
		Skills: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"Node.js", "GraphQL", "REST APIs"},
		}},
		Certifications: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"MongoDB Certified Developer"},
		}},
		ProjectHistory: GetProjectHistoryByEmployeeId(8),
	},
	{
		Id: 9,
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{
			Items: []*projects.Project{ServiceProjects[3], ServiceProjects[4]},
		}},
		AssignedTasks:  GetAssignedTasksByEmployeeId(9),
		CompletedTasks: GetCompletedTasksByEmployeeId(9),
		Skills: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"DevOps", "Terraform", "Ansible"},
		}},
		Certifications: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"HashiCorp Certified Terraform Associate"},
		}},
		ProjectHistory: GetProjectHistoryByEmployeeId(9),
	},
	{
		Id: 10,
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{
			Items: []*projects.Project{ServiceProjects[4]},
		}},
		AssignedTasks:  GetAssignedTasksByEmployeeId(10),
		CompletedTasks: GetCompletedTasksByEmployeeId(10),
		Skills: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"Backend", "Go", "Docker"},
		}},
		Certifications: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"HashiCorp Certified Terraform Associate"},
		}},
		ProjectHistory: GetProjectHistoryByEmployeeId(10),
	},
	{
		Id: 11,
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{
			Items: []*projects.Project{ServiceProjects[5]},
		}},
		AssignedTasks:  GetAssignedTasksByEmployeeId(11),
		CompletedTasks: GetCompletedTasksByEmployeeId(11),
		Skills: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"Frontend", "React", "TypeScript"},
		}},
		Certifications: nil,
		ProjectHistory: GetProjectHistoryByEmployeeId(11),
	},
	{
		Id: 12,
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{
			Items: []*projects.Project{ServiceProjects[6]},
		}},
		AssignedTasks:  GetAssignedTasksByEmployeeId(12),
		CompletedTasks: GetCompletedTasksByEmployeeId(12),
		Skills: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"Backend", "Go", "Docker"},
		}},
		Certifications: &projects.ListOfString{List: &projects.ListOfString_List{
			Items: []string{"HashiCorp Certified Terraform Associate"},
		}},
		ProjectHistory: GetProjectHistoryByEmployeeId(12),
	},
}
var ServiceMilestones = []*projects.Milestone{
	{
		Id:                   "1",
		ProjectId:            "1",
		Name:                 "Infrastructure Assessment",
		Description:          &wrapperspb.StringValue{Value: "Evaluate current infrastructure and plan migration"},
		StartDate:            &wrapperspb.StringValue{Value: "2021-01-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2021-03-31"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_COMPLETED,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 100.0},
		Dependencies:         []*projects.Milestone{},
		Subtasks:             &projects.ListOfTask{List: &projects.ListOfTask_List{Items: []*projects.Task{}}},
		Reviewers:            &projects.ListOfEmployee{List: &projects.ListOfEmployee_List{Items: []*projects.Employee{}}},
	},
	{
		Id:                   "2",
		ProjectId:            "1",
		Name:                 "Cloud Environment Setup",
		Description:          &wrapperspb.StringValue{Value: "Set up AWS/Azure environments and networking"},
		StartDate:            &wrapperspb.StringValue{Value: "2021-04-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2021-06-30"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_IN_PROGRESS,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 65.0},
		Dependencies:         []*projects.Milestone{},
		Subtasks:             nil,
		Reviewers:            &projects.ListOfEmployee{List: &projects.ListOfEmployee_List{Items: []*projects.Employee{}}},
	},
	{
		Id:                   "3",
		ProjectId:            "1",
		Name:                 "Application Migration",
		Description:          &wrapperspb.StringValue{Value: "Migrate applications to cloud infrastructure"},
		StartDate:            &wrapperspb.StringValue{Value: "2021-07-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2025-08-20"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_PENDING,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 25.0},
		Dependencies:         []*projects.Milestone{},
		Subtasks:             &projects.ListOfTask{List: &projects.ListOfTask_List{Items: []*projects.Task{}}},
		Reviewers:            &projects.ListOfEmployee{List: &projects.ListOfEmployee_List{Items: []*projects.Employee{}}},
	},
	{
		Id:                   "4",
		ProjectId:            "2",
		Name:                 "Service Decomposition",
		Description:          &wrapperspb.StringValue{Value: "Analyze monolith and define service boundaries"},
		StartDate:            &wrapperspb.StringValue{Value: "2021-01-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2021-04-30"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_COMPLETED,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 100.0},
		Dependencies:         []*projects.Milestone{},
		Subtasks:             &projects.ListOfTask{List: &projects.ListOfTask_List{Items: []*projects.Task{}}},
		Reviewers:            &projects.ListOfEmployee{List: &projects.ListOfEmployee_List{Items: []*projects.Employee{}}},
	},
	{
		Id:                   "5",
		ProjectId:            "2",
		Name:                 "API Gateway Implementation",
		Description:          &wrapperspb.StringValue{Value: "Implement API gateway and service mesh"},
		StartDate:            &wrapperspb.StringValue{Value: "2021-05-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2022-12-31"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_IN_PROGRESS,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 70.0},
	},
	{
		Id:                   "6",
		ProjectId:            "2",
		Name:                 "Service Deployment",
		Description:          &wrapperspb.StringValue{Value: "Deploy and orchestrate microservices"},
		StartDate:            &wrapperspb.StringValue{Value: "2023-01-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2025-08-20"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_PENDING,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 45.0},
	},
	{
		Id:                   "7",
		ProjectId:            "6",
		Name:                 "UI/UX Research",
		Description:          &wrapperspb.StringValue{Value: "Conduct user research and design new interfaces"},
		StartDate:            &wrapperspb.StringValue{Value: "2022-01-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2022-06-30"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_COMPLETED,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 100.0},
	},
	{
		Id:                   "8",
		ProjectId:            "6",
		Name:                 "Flutter Implementation",
		Description:          &wrapperspb.StringValue{Value: "Implement new mobile apps using Flutter"},
		StartDate:            &wrapperspb.StringValue{Value: "2022-07-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2023-01-31"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_COMPLETED,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 100.0},
	},
	{
		Id:                   "9",
		ProjectId:            "7",
		Name:                 "Data Architecture Design",
		Description:          &wrapperspb.StringValue{Value: "Design data lake architecture and data flow"},
		StartDate:            &wrapperspb.StringValue{Value: "2023-01-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2023-06-30"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_COMPLETED,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 100.0},
	},
	{
		Id:                   "10",
		ProjectId:            "7",
		Name:                 "Data Ingestion Pipeline",
		Description:          &wrapperspb.StringValue{Value: "Build automated data ingestion and processing"},
		StartDate:            &wrapperspb.StringValue{Value: "2023-07-01"},
		EndDate:              &wrapperspb.StringValue{Value: "2024-12-31"},
		Status:               projects.MilestoneStatus_MILESTONE_STATUS_IN_PROGRESS,
		CompletionPercentage: &wrapperspb.DoubleValue{Value: 30.0},
	},
}
var ServiceProducts = []*projects.Product{
	{
		Upc:      "cosmo",
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{ServiceProjects[0], ServiceProjects[1], ServiceProjects[3]}}},

		FeatureMatrix: &projects.ListOfListOfString{
			List: &projects.ListOfListOfString_List{
				Items: []*projects.ListOfString{
					{List: &projects.ListOfString_List{Items: []string{"federation", "routing", "composition"}}},
					{List: &projects.ListOfString_List{Items: []string{"monitoring", "analytics", "tracing"}}},
					{List: &projects.ListOfString_List{}},
					{List: &projects.ListOfString_List{Items: []string{""}}},
					nil,
				},
			},
		},
	},
	{
		Upc:      "sdk",
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{ServiceProjects[2], ServiceProjects[6]}}},

		FeatureMatrix: nil,
	},
	{
		Upc:      "consultancy",
		Projects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{ServiceProjects[4], ServiceProjects[5]}}},

		FeatureMatrix: &projects.ListOfListOfString{
			List: &projects.ListOfListOfString_List{
				Items: []*projects.ListOfString{
					{List: &projects.ListOfString_List{Items: []string{"architecture", "best-practices"}}},
					{List: &projects.ListOfString_List{Items: []string{"training", "mentoring"}}},
				},
			},
		},
	},
}
var ServiceProjectUpdates = []*projects.ProjectUpdate{
	{
		Id:          "1",
		ProjectId:   "1",
		UpdatedById: 1,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_STATUS_CHANGE,
		Description: "Project status changed from PLANNING to ACTIVE",
		Timestamp:   "2021-01-01T09:00:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"old_status": "PLANNING", "new_status": "ACTIVE"}`},
	},
	{
		Id:          "2",
		ProjectId:   "1",
		UpdatedById: 2,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_MILESTONE_ADDED,
		Description: "Added milestone: Infrastructure Assessment",
		Timestamp:   "2021-01-02T10:30:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"milestone_id": "1", "milestone_name": "Infrastructure Assessment"}`},
	},
	{
		Id:          "3",
		ProjectId:   "2",
		UpdatedById: 7,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_TASK_ASSIGNED,
		Description: "Task assigned: Domain Model Analysis to employee #7",
		Timestamp:   "2021-01-01T11:15:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"task_id": "4", "assignee_id": "7"}`},
	},
	{
		Id:          "4",
		ProjectId:   "3",
		UpdatedById: 5,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_PROGRESS_UPDATE,
		Description: "Project progress updated to 45%",
		Timestamp:   "2021-06-15T14:20:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"old_progress": "30", "new_progress": "45"}`},
	},
	{
		Id:          "5",
		ProjectId:   "4",
		UpdatedById: 1,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_STATUS_CHANGE,
		Description: "Project moved to PLANNING phase",
		Timestamp:   "2023-03-01T08:00:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"old_status": "DRAFT", "new_status": "PLANNING"}`},
	},
	{
		Id:          "6",
		ProjectId:   "5",
		UpdatedById: 2,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_STATUS_CHANGE,
		Description: "Project put ON_HOLD due to security concerns",
		Timestamp:   "2023-06-15T16:45:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"old_status": "ACTIVE", "new_status": "ON_HOLD", "reason": "security_concerns"}`},
	},
	{
		Id:          "7",
		ProjectId:   "6",
		UpdatedById: 3,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_STATUS_CHANGE,
		Description: "Mobile App Redesign project completed successfully",
		Timestamp:   "2023-01-31T17:30:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"old_status": "ACTIVE", "new_status": "COMPLETED"}`},
	},
	{
		Id:          "8",
		ProjectId:   "7",
		UpdatedById: 5,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_TEAM_CHANGE,
		Description: "Added new team member to Data Lake Implementation",
		Timestamp:   "2023-02-15T10:00:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"action": "add", "employee_id": "12", "role": "data_engineer"}`},
	},
	{
		Id:          "9",
		ProjectId:   "2",
		UpdatedById: 8,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_PROGRESS_UPDATE,
		Description: "Microservices Revolution reached 75% completion",
		Timestamp:   "2024-01-10T13:25:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"old_progress": "70", "new_progress": "75"}`},
	},
	{
		Id:          "10",
		ProjectId:   "1",
		UpdatedById: 3,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_MILESTONE_ADDED,
		Description: "Added milestone: Application Migration",
		Timestamp:   "2021-06-30T15:00:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"milestone_id": "3", "milestone_name": "Application Migration"}`},
	},
	{
		Id:          "11",
		ProjectId:   "7",
		UpdatedById: 12,
		UpdateType:  projects.ProjectUpdateType_PROJECT_UPDATE_TYPE_TASK_ASSIGNED,
		Description: "Task assigned: Apache Spark Integration to employee #12",
		Timestamp:   "2023-08-01T09:30:00Z",
		Metadata:    &wrapperspb.StringValue{Value: `{"task_id": "13", "assignee_id": "12"}`},
	},
}
var ServiceProjects = []*projects.Project{
	{
		Id:                  "1",
		Name:                "Cloud Migration Overhaul",
		Description:         &wrapperspb.StringValue{Value: "Migrate legacy systems to cloud-native architecture"},
		Status:              projects.ProjectStatus_PROJECT_STATUS_ACTIVE,
		StartDate:           &wrapperspb.StringValue{Value: "2021-01-01"},
		EndDate:             &wrapperspb.StringValue{Value: "2025-08-20"},
		TeamMembers:         []*projects.Employee{},
		RelatedProducts:     []*projects.Product{},
		MilestoneIds:        &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"1", "2", "3"}}},
		Milestones:          GetMilestonesByProjectID("1"),
		Tasks:               GetTasksByProjectID("1"),
		Progress:            &wrapperspb.DoubleValue{Value: 65.0},
		Tags:                &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"cloud", "migration", "priority"}}},
		AlternativeProjects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		Dependencies:        &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		ResourceGroups:      &projects.ListOfListOfProjectResource{},
		TasksByPhase:        &projects.ListOfListOfTask{},
		MilestoneGroups:     &projects.ListOfListOfMilestone{},
		PriorityMatrix:      &projects.ListOfListOfListOfTask{},
	},
	{
		Id:                  "2",
		Name:                "Microservices Revolution",
		Description:         &wrapperspb.StringValue{Value: "Break down monolith into microservices"},
		Status:              projects.ProjectStatus_PROJECT_STATUS_ACTIVE,
		StartDate:           &wrapperspb.StringValue{Value: "2021-01-01"},
		EndDate:             &wrapperspb.StringValue{Value: "2025-08-20"},
		TeamMembers:         []*projects.Employee{},
		RelatedProducts:     []*projects.Product{},
		MilestoneIds:        &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"4", "5", "6"}}},
		Milestones:          GetMilestonesByProjectID("2"),
		Tasks:               GetTasksByProjectID("2"),
		Progress:            &wrapperspb.DoubleValue{Value: 75.0},
		Tags:                &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"microservices", "architecture"}}},
		AlternativeProjects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		Dependencies:        &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		ResourceGroups:      &projects.ListOfListOfProjectResource{},
		TasksByPhase:        &projects.ListOfListOfTask{},
		MilestoneGroups:     &projects.ListOfListOfMilestone{},
		PriorityMatrix:      &projects.ListOfListOfListOfTask{},
	},
	{
		Id:                  "3",
		Name:                "AI-Powered Analytics",
		Description:         &wrapperspb.StringValue{Value: "Implement machine learning for business intelligence"},
		Status:              projects.ProjectStatus_PROJECT_STATUS_ACTIVE,
		StartDate:           &wrapperspb.StringValue{Value: "2021-01-01"},
		EndDate:             &wrapperspb.StringValue{Value: "2025-08-20"},
		TeamMembers:         []*projects.Employee{},
		RelatedProducts:     []*projects.Product{},
		MilestoneIds:        &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{}}},
		Milestones:          GetMilestonesByProjectID("3"),
		Tasks:               GetTasksByProjectID("3"),
		Progress:            &wrapperspb.DoubleValue{Value: 45.0},
		Tags:                nil,
		AlternativeProjects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		Dependencies:        &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		ResourceGroups:      &projects.ListOfListOfProjectResource{},
		TasksByPhase:        &projects.ListOfListOfTask{},
		MilestoneGroups:     nil,
		PriorityMatrix:      &projects.ListOfListOfListOfTask{},
	},
	{
		Id:                  "4",
		Name:                "DevOps Transformation",
		Description:         &wrapperspb.StringValue{Value: "Implement CI/CD and infrastructure as code"},
		Status:              projects.ProjectStatus_PROJECT_STATUS_PLANNING,
		StartDate:           &wrapperspb.StringValue{Value: "2023-03-01"},
		EndDate:             &wrapperspb.StringValue{Value: "2024-12-31"},
		TeamMembers:         []*projects.Employee{},
		RelatedProducts:     []*projects.Product{},
		MilestoneIds:        &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{}}},
		Milestones:          GetMilestonesByProjectID("4"),
		Tasks:               GetTasksByProjectID("4"),
		Progress:            &wrapperspb.DoubleValue{Value: 10.0},
		Tags:                &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"devops", "ci-cd", "infrastructure"}}},
		AlternativeProjects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		Dependencies:        &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		ResourceGroups:      &projects.ListOfListOfProjectResource{},
		TasksByPhase:        &projects.ListOfListOfTask{},
		MilestoneGroups:     &projects.ListOfListOfMilestone{},
		PriorityMatrix:      &projects.ListOfListOfListOfTask{},
	},
	{
		Id:                  "5",
		Name:                "Security Overhaul",
		Description:         &wrapperspb.StringValue{Value: "Implement zero-trust security architecture"},
		Status:              projects.ProjectStatus_PROJECT_STATUS_ON_HOLD,
		StartDate:           &wrapperspb.StringValue{Value: "2023-06-01"},
		EndDate:             &wrapperspb.StringValue{Value: "2024-06-30"},
		TeamMembers:         []*projects.Employee{},
		RelatedProducts:     []*projects.Product{},
		MilestoneIds:        &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{}}},
		Milestones:          GetMilestonesByProjectID("5"),
		Tasks:               GetTasksByProjectID("5"),
		Progress:            &wrapperspb.DoubleValue{Value: 5.0},
		Tags:                &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"security", "zero-trust"}}},
		AlternativeProjects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		Dependencies:        &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		ResourceGroups:      &projects.ListOfListOfProjectResource{},
		TasksByPhase:        &projects.ListOfListOfTask{},
		MilestoneGroups:     &projects.ListOfListOfMilestone{},
		PriorityMatrix:      &projects.ListOfListOfListOfTask{},
	},
	{
		Id:                  "6",
		Name:                "Mobile App Development",
		Description:         &wrapperspb.StringValue{Value: "Build native mobile applications for iOS and Android"},
		Status:              projects.ProjectStatus_PROJECT_STATUS_ACTIVE,
		StartDate:           &wrapperspb.StringValue{Value: "2023-09-01"},
		EndDate:             &wrapperspb.StringValue{Value: "2024-09-30"},
		TeamMembers:         []*projects.Employee{},
		RelatedProducts:     []*projects.Product{},
		MilestoneIds:        &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"7", "8"}}},
		Milestones:          GetMilestonesByProjectID("6"),
		Tasks:               GetTasksByProjectID("6"),
		Progress:            &wrapperspb.DoubleValue{Value: 30.0},
		Tags:                &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"mobile", "ios", "android"}}},
		AlternativeProjects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		Dependencies:        &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		ResourceGroups:      &projects.ListOfListOfProjectResource{},
		TasksByPhase:        &projects.ListOfListOfTask{},
		MilestoneGroups:     &projects.ListOfListOfMilestone{},
		PriorityMatrix:      &projects.ListOfListOfListOfTask{},
	},
	{
		Id:                  "7",
		Name:                "Data Lake Implementation",
		Description:         &wrapperspb.StringValue{Value: "Build enterprise data lake for analytics"},
		Status:              projects.ProjectStatus_PROJECT_STATUS_ACTIVE,
		StartDate:           &wrapperspb.StringValue{Value: "2023-01-01"},
		EndDate:             &wrapperspb.StringValue{Value: "2024-12-31"},
		TeamMembers:         []*projects.Employee{},
		RelatedProducts:     []*projects.Product{},
		MilestoneIds:        &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"9", "10"}}},
		Milestones:          GetMilestonesByProjectID("7"),
		Tasks:               GetTasksByProjectID("7"),
		Progress:            &wrapperspb.DoubleValue{Value: 40.0},
		Tags:                &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"data", "analytics", "lake"}}},
		AlternativeProjects: &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		Dependencies:        &projects.ListOfProject{List: &projects.ListOfProject_List{Items: []*projects.Project{}}},
		ResourceGroups:      &projects.ListOfListOfProjectResource{},
		TasksByPhase:        &projects.ListOfListOfTask{},
		MilestoneGroups:     &projects.ListOfListOfMilestone{},
		PriorityMatrix:      &projects.ListOfListOfListOfTask{},
	},
}
var ServiceTasks = []*projects.Task{
	{
		Id:             "1",
		ProjectId:      "1",
		MilestoneId:    &wrapperspb.StringValue{Value: "1"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 1},
		Name:           "Current Infrastructure Audit",
		Description:    &wrapperspb.StringValue{Value: "Document existing servers, databases, and applications"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_COMPLETED,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 40.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 45.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2021-01-01T00:00:00Z"},
		CompletedAt:    &wrapperspb.StringValue{Value: "2021-01-15T17:30:00Z"},
		Labels:         &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"audit", "infrastructure", "high-priority"}}},
		Subtasks:       &projects.ListOfTask{List: &projects.ListOfTask_List{Items: []*projects.Task{}}},
		Dependencies:   []*projects.Task{},
		AttachmentUrls: []string{"https://docs.company.com/audit-report.pdf", "https://drive.company.com/infrastructure-map"},
		ReviewerIds:    &projects.ListOfInt{List: &projects.ListOfInt_List{Items: []int32{2, 3}}},
	},
	{
		Id:             "2",
		ProjectId:      "1",
		MilestoneId:    &wrapperspb.StringValue{Value: "1"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 2},
		Name:           "Cloud Provider Selection",
		Description:    &wrapperspb.StringValue{Value: "Evaluate AWS, Azure, and GCP options"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_COMPLETED,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 24.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 20.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2021-01-16T00:00:00Z"},
		CompletedAt:    &wrapperspb.StringValue{Value: "2021-02-28T16:00:00Z"},
		Labels:         nil,
		Subtasks:       &projects.ListOfTask{List: &projects.ListOfTask_List{}},
		Dependencies:   []*projects.Task{},
		AttachmentUrls: []string{"https://docs.company.com/cloud-comparison.xlsx"},
		ReviewerIds:    &projects.ListOfInt{List: &projects.ListOfInt_List{Items: []int32{1, 4}}},
	},
	{
		Id:             "3",
		ProjectId:      "1",
		MilestoneId:    &wrapperspb.StringValue{Value: "2"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 3},
		Name:           "Network Setup",
		Description:    &wrapperspb.StringValue{Value: "Configure VPCs, subnets, and security groups"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_MEDIUM,
		Status:         projects.TaskStatus_TASK_STATUS_IN_PROGRESS,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 32.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 25.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2021-04-01T00:00:00Z"},
		CompletedAt:    nil,
		Labels:         &projects.ListOfString{List: &projects.ListOfString_List{Items: []string{"networking", "cloud", "security"}}},
		Subtasks:       &projects.ListOfTask{List: &projects.ListOfTask_List{Items: []*projects.Task{}}},
		Dependencies:   []*projects.Task{},
		AttachmentUrls: []string{},
		ReviewerIds:    &projects.ListOfInt{List: &projects.ListOfInt_List{Items: []int32{2}}},
	},
	{
		Id:             "4",
		ProjectId:      "2",
		MilestoneId:    &wrapperspb.StringValue{Value: "4"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 7},
		Name:           "Domain Model Analysis",
		Description:    &wrapperspb.StringValue{Value: "Identify bounded contexts and service boundaries"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_COMPLETED,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 50.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 48.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2021-01-01T00:00:00Z"},
		CompletedAt:    &wrapperspb.StringValue{Value: "2021-03-15T18:00:00Z"},
	},
	{
		Id:             "5",
		ProjectId:      "2",
		MilestoneId:    &wrapperspb.StringValue{Value: "5"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 8},
		Name:           "API Gateway Configuration",
		Description:    &wrapperspb.StringValue{Value: "Set up Kong or AWS API Gateway"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_IN_PROGRESS,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 30.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 22.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2021-05-01T00:00:00Z"},
		CompletedAt:    nil,
	},
	{
		Id:             "6",
		ProjectId:      "3",
		Name:           "Machine Learning Model Research",
		Description:    &wrapperspb.StringValue{Value: "Research and prototype ML models for business analytics"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_MEDIUM,
		Status:         projects.TaskStatus_TASK_STATUS_IN_PROGRESS,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 60.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 35.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2021-01-01T00:00:00Z"},
		CompletedAt:    nil,
	},
	{
		Id:             "7",
		ProjectId:      "3",
		MilestoneId:    nil,
		AssigneeId:     &wrapperspb.Int32Value{Value: 7},
		Name:           "Data Pipeline Design",
		Description:    &wrapperspb.StringValue{Value: "Design ETL pipelines for analytics data"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_TODO,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 45.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 0.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2021-02-01T00:00:00Z"},
		CompletedAt:    nil,
	},
	{
		Id:             "8",
		ProjectId:      "4",
		MilestoneId:    nil,
		AssigneeId:     &wrapperspb.Int32Value{Value: 1},
		Name:           "CI/CD Pipeline Setup",
		Description:    &wrapperspb.StringValue{Value: "Implement GitLab CI or GitHub Actions"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_TODO,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 35.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 0.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2023-03-01T00:00:00Z"},
		CompletedAt:    nil,
	},
	{
		Id:             "9",
		ProjectId:      "5",
		MilestoneId:    nil,
		AssigneeId:     &wrapperspb.Int32Value{Value: 2},
		Name:           "Security Assessment",
		Description:    &wrapperspb.StringValue{Value: "Conduct comprehensive security audit"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_URGENT,
		Status:         projects.TaskStatus_TASK_STATUS_BLOCKED,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 80.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 10.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2023-06-01T00:00:00Z"},
		CompletedAt:    nil,
	},
	{
		Id:             "10",
		ProjectId:      "6",
		MilestoneId:    &wrapperspb.StringValue{Value: "7"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 3},
		Name:           "User Experience Testing",
		Description:    &wrapperspb.StringValue{Value: "Conduct usability testing with focus groups"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_MEDIUM,
		Status:         projects.TaskStatus_TASK_STATUS_COMPLETED,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 25.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 28.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2022-03-01T00:00:00Z"},
		CompletedAt:    &wrapperspb.StringValue{Value: "2022-05-15T16:00:00Z"},
	},
	{
		Id:             "11",
		ProjectId:      "6",
		MilestoneId:    &wrapperspb.StringValue{Value: "8"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 11},
		Name:           "Flutter App Development",
		Description:    &wrapperspb.StringValue{Value: "Develop cross-platform mobile application"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_COMPLETED,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 120.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 115.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2022-07-01T00:00:00Z"},
		CompletedAt:    &wrapperspb.StringValue{Value: "2022-12-20T17:30:00Z"},
	},
	{
		Id:             "12",
		ProjectId:      "7",
		MilestoneId:    &wrapperspb.StringValue{Value: "9"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 5},
		Name:           "Data Schema Design",
		Description:    &wrapperspb.StringValue{Value: "Design schema for structured and unstructured data"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_COMPLETED,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 40.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 42.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2023-01-15T00:00:00Z"},
		CompletedAt:    &wrapperspb.StringValue{Value: "2023-04-10T18:00:00Z"},
	},
	{
		Id:             "13",
		ProjectId:      "7",
		MilestoneId:    &wrapperspb.StringValue{Value: "10"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 12},
		Name:           "Apache Spark Integration",
		Description:    &wrapperspb.StringValue{Value: "Set up Spark clusters for data processing"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_MEDIUM,
		Status:         projects.TaskStatus_TASK_STATUS_IN_PROGRESS,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 55.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 30.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2023-08-01T00:00:00Z"},
		CompletedAt:    nil,
	},
	{
		Id:             "14",
		ProjectId:      "1",
		MilestoneId:    &wrapperspb.StringValue{Value: "3"},
		AssigneeId:     &wrapperspb.Int32Value{Value: 1},
		Name:           "Database Migration",
		Description:    &wrapperspb.StringValue{Value: "Migrate databases to cloud-managed services"},
		Priority:       projects.TaskPriority_TASK_PRIORITY_HIGH,
		Status:         projects.TaskStatus_TASK_STATUS_TODO,
		EstimatedHours: &wrapperspb.DoubleValue{Value: 65.0},
		ActualHours:    &wrapperspb.DoubleValue{Value: 0.0},
		CreatedAt:      &wrapperspb.StringValue{Value: "2021-07-01T00:00:00Z"},
		CompletedAt:    nil,
	},
}

Functions

func GetAllProjectTags

func GetAllProjectTags() *projects.ListOfString

Helper function to get all unique project tags

func GetAlternativeProjects

func GetAlternativeProjects(projectID string) *projects.ListOfProject

Helper function to get alternative projects

func GetArchivedProjects

func GetArchivedProjects() []*projects.Project

Helper function to get archived projects (for testing nullable list of nullable projects)

func GetAssignedTasksByEmployeeId

func GetAssignedTasksByEmployeeId(employeeId int32) []*projects.Task

Helper function to get assigned tasks by employee ID

func GetCompletedTasksByEmployeeId

func GetCompletedTasksByEmployeeId(employeeId int32) []*projects.Task

Helper function to get completed tasks by employee ID

func GetEmployeeByID

func GetEmployeeByID(id int32) *projects.Employee

Helper function to get employee by ID

func GetEmployeeById

func GetEmployeeById(id int32) *projects.Employee

Helper function to get employee by ID

func GetMilestoneByID

func GetMilestoneByID(id string) *projects.Milestone

Helper function to get milestone by ID

func GetMilestoneDependencies

func GetMilestoneDependencies(milestoneID string) []*projects.Milestone

Helper function to get milestone dependencies

func GetMilestoneGroups

func GetMilestoneGroups(projectID string) *projects.ListOfListOfMilestone

Helper function to get milestone groups

func GetMilestoneReviewers

func GetMilestoneReviewers(milestoneID string) *projects.ListOfEmployee

Helper function to get milestone reviewers

func GetMilestoneSubtasks

func GetMilestoneSubtasks(milestoneID string) *projects.ListOfTask

Helper function to get milestone subtasks

func GetMilestonesByProjectID

func GetMilestonesByProjectID(projectID string) []*projects.Milestone

Helper function to get milestones by project ID

func GetPriorityMatrix

func GetPriorityMatrix(projectID string) *projects.ListOfListOfListOfTask

Helper function to get priority matrix (triple nested lists)

func GetProductByUpc

func GetProductByUpc(upc string) *projects.Product

func GetProjectByID

func GetProjectByID(id string) *projects.Project

Helper function to get project by ID

func GetProjectDependencies

func GetProjectDependencies(projectID string) *projects.ListOfProject

Helper function to get project dependencies

func GetProjectHistoryByEmployeeId

func GetProjectHistoryByEmployeeId(employeeId int32) *projects.ListOfListOfProject

Helper function to get project history for an employee (grouped by time periods)

func GetProjectUpdateById

func GetProjectUpdateById(id string) *projects.ProjectUpdate

Helper function to get project update by ID

func GetProjectUpdatesByProjectID

func GetProjectUpdatesByProjectID(projectID string) []*projects.ProjectUpdate

Helper function to get project updates by project ID

func GetResourceGroups

func GetResourceGroups(projectID string) *projects.ListOfListOfProjectResource

Helper function to get resource groups

func GetTaskByID

func GetTaskByID(id string) *projects.Task

Helper function to get task by ID

func GetTaskDependencies

func GetTaskDependencies(taskID string) []*projects.Task

Helper function to get task dependencies

func GetTaskSubtasks

func GetTaskSubtasks(taskID string) *projects.ListOfTask

Helper function to get task subtasks

func GetTasksByMilestoneID

func GetTasksByMilestoneID(milestoneID string) []*projects.Task

Helper function to get tasks by milestone ID

func GetTasksByPhase

func GetTasksByPhase(projectID string) *projects.ListOfListOfTask

Helper function to get tasks grouped by phase (status)

func GetTasksByProjectID

func GetTasksByProjectID(projectID string) []*projects.Task

Helper function to get tasks by project ID

func GetTeamMembersByProjectId

func GetTeamMembersByProjectId(projectID string) []*projects.Employee

func PopulateMilestoneRelationships

func PopulateMilestoneRelationships(milestone *projects.Milestone) *projects.Milestone

Function to populate milestone with its relationships (call this dynamically, not during initialization)

func PopulateTaskRelationships

func PopulateTaskRelationships(task *projects.Task) *projects.Task

Function to populate task with its relationships (call this dynamically, not during initialization)

Types

This section is empty.

Jump to